# Changes

## v1.0.1 (2025-12-15)

### Fix

- support alternate lookup fields on CRUD resources

## v1.0.0 (2025-12-15)

### Feat

- adds view utilities to reduce boilerplate when creating typical CRUD views
- add OpenAPI 3.1 spec generation with auto-endpoint support


- drop support for django <= 5.1

## v0.2.0 (2025-12-05)

### Feat

- add decorator support to Router and Route
- support Python 3.14

### Fix

- **deps**: update dependency django-stubs-ext to >=5.2.8
- **deps**: update dependency pydantic to >=2.12.5,<3.0.0
- **deps**: update dependency pydantic to >=2.12.4,<3.0.0
- **deps**: update dependency pydantic to >=2.12.3,<3.0.0
- **deps**: update dependency pydantic to >=2.12.2,<3.0.0
- **deps**: update dependency pydantic to >=2.12.0,<3.0.0
- **deps**: update dependency django-stubs-ext to >=5.2.7
- **deps**: update dependency django-stubs-ext to >=5.2.6
- **deps**: update dependency pydantic to >=2.11.10,<3.0.0
- **deps**: update dependency pydantic to >=2.11.9,<3.0.0
- **deps**: update dependency pydantic to >=2.11.8,<3.0.0
- **deps**: update dependency django-stubs-ext to >=5.2.5
- **deps**: update dependency django-stubs-ext to >=5.2.4
- **deps**: update dependency pydantic to >=2.11.7,<3.0.0
- **deps**: update dependency djangorestframework to >=3.16.1
- **deps**: update dependency django-stubs-ext to >=5.2.2
- prevent renovate from pointing all URLs at gitlab

## v0.1.1 (2025-09-03)

### Fix

- update version constraint to allow django 5.2
- **deps**: update dependency pydantic to >=2.11.3,<3.0.0
- **deps**: update dependency pydantic to >=2.11.2,<3.0.0

### Refactor

- migrate black/flake8 -> ruff

## v0.1.0 (2025-04-03)

### Feat

- support Django 5.2. Drop Django 5.0

### Fix

- **deps**: update dependency pydantic to >=2.11.1,<3.0.0
- **deps**: update dependency pydantic to >=2.11.0,<3.0.0
- **deps**: update dependency djangorestframework to >=3.16.0

### Refactor

- add pyupgrade / django-upgrade precommit hooks

## v0.1.0b5 (2025-03-21)

## v0.1.0b4 (2025-03-19)

### Feat

- add api router index view

### Fix

- **deps**: update dependency django-stubs-ext to >=5.1.3

## v0.1.0b3 (2025-03-19)

## v0.1.0b2 (2025-03-19)

### Feat

- add Router class for view routing by HTTP method

## v0.1.0b1 (2025-03-17)

### Feat

- add FastAPI-inspired utils for building typed views in Django

## v0.1.0b0 (2025-03-11)

### Feat

- add partition_results func
- add Result types

## v0.1.0a1 (2025-03-07)

### Feat

- add thelabtyping.drf.renderers
- add thelabtyping.abc.ListOf

## v0.1.0a0 (2025-03-07)

### Feat

- initial commit
